# Introduction

Hw1lib is a library package for the homework1 of Data Engineering Course.

This is a package of currency classes for storing FOREX data.

Including the classes for the currency pairs listed below:

- AUD-USD
- GBP-EUR
- USD-CAD
- USD-JPY
- USD-MXN
- EUR-USD
- USD-CNY
- USD-CZK
- USD-PLN
- USD-INR

This is a test project, so these classes are designed for special functionality. 